==> moodle_1.3.1.orig.tar.gz: moodle/lang/fi/calendar.php <==
<?PHP // $Id: calendar.php,v 1.4 2004/05/23 11:36:21 paca70 Exp $ 
      // calendar.php - created with Moodle 1.3 Beta + (2004051600)


$string['april'] = 'Huhtikuu';
$string['august'] = 'Elokuu';
$string['calendar'] = 'Kalenteri';
$string['calendarheading'] = 'Oma kalenteri';
$string['clickhide'] = 'klikkaa piilottaaksesi';
$string['clickshow'] = 'klikkaa nyttksesi';
$string['confirmeventdelete'] = 'Haluatko varmasti poistaa tmn tapahtuman';
$string['courseevents'] = 'Kurssin tapahtumat';
$string['dayview'] = 'Pivnkym';
$string['daywithnoevents'] = 'Ei tapahtumia tlle pivlle';
$string['december'] = 'Joulukuu';
$string['default'] = 'Oletus';
$string['deleteevent'] = 'Poista tapahtuma';
$string['detailedmonthview'] = 'Tarkennettu kuukausinkym';
$string['durationminutes'] = 'Kesto minuutteina';
$string['durationnone'] = 'Ilman kestoa';
$string['durationuntil'] = 'Pttymisaika';
$string['editevent'] = 'Muokkaa tapahtumaa';
$string['errorbeforecoursestart'] = 'Tapahtumaa ei voi asettaa alkavaksi ennen kurssin aloituspiv';
$string['errorinvaliddate'] = 'Pivmr virheellinen';
$string['errorinvalidminutes'] = 'Mrit kesto 1 ja 999 minuutin vlilt.';
$string['errorinvalidrepeats'] = 'Mrit tapahtumien mr 1 ja 99 vlill.';
$string['errornodescription'] = 'Tapahtuman kuvaus puuttuu';
$string['errornoeventname'] = 'Tapahtuman nimi puuttuu';
$string['eventdate'] = 'Pivmr';
$string['eventdescription'] = 'Tapahtuman kuvaus';
$string['eventduration'] = 'Kesto';
$string['eventendtime'] = 'Tapahtuman pttymisaika';
$string['eventinstanttime'] = 'Aika';
$string['eventkind'] = 'Tapahtuman tyyppi';
$string['eventname'] = 'Nimi';
$string['eventrepeat'] = 'Toistot';
$string['eventsfor'] = '$a tapahtumaa';
$string['eventstarttime'] = 'Tapahtuman alkamisaika';
$string['eventtime'] = 'Aika';
$string['eventview'] = 'Tapahtumankym';
$string['expired'] = 'Tapahtuma on jo mennyt';
$string['explain_lookahead'] = 'Tm oletusasetus mritt, kuinka monen pivn pss tulevaisuudessa tapahtuman pit olla, jotta se nytettisiin \"tulevana tapahtumana\". Tapahtumia, jotka alkavat myhemmin, ei nytet koskaan tulevien tapahtumien listassa. Huomaa, ett <strong>ei ole mitn takeita</strong> siit, ett kaikki tmn ajan sisll olevat tapahtumat nytettisiin tulevien listassa; mikli niit on paljon (enemmn kuin asetus \"Tulevien tapahtumien listan maksimikoko\", kaukaisimmat tulevista tapahtumista eivt ny listassa.';
$string['explain_maxevents'] = 'Tm asetus mritt tulevien tapahtumien listan maksimikoon. Mikli valitset thn suuren luvun, saattaa tulevien tapahtumien lista vied huomattavan paljon tilaa ruudultasi.';
$string['explain_startwday'] = 'Tm asetus mritt tavan, jolla kuukausittainen kalenteri nytetn. Kyt tt asettaaksesi nkymlle tavan, johon olet tottunut.';
$string['explain_timeformat'] = 'Voit ntt ajatjoko 12 tai 24 tunnin muodossa. Jos valitset \"oletus\", valinta suoritetaan sivuston asetusten maukaisesti.';
$string['february'] = 'Helmikuu';
$string['fri'] = 'Pe';
$string['friday'] = 'Perjantai';
$string['globalevents'] = 'Yhteiset tapahtumat';
$string['gotocalendar'] = 'Siirry kalenteriin';
$string['groupevents'] = 'Ryhmn tapahtumat';
$string['hidden'] = 'Piilotettu';
$string['january'] = 'Tammikuu';
$string['july'] = 'Heinkuu';
$string['june'] = 'Keskuu';
$string['manyevents'] = '$a tapahtumaa';
$string['march'] = 'Maaliskuu';
$string['may'] = 'Toukokuu';
$string['mon'] = 'Ma';
$string['monday'] = 'Maanantai';
$string['monthlyview'] = 'Kuukausinkym';
$string['newevent'] = 'Uusi tapahtuma';
$string['noupcomingevents'] = 'Ei tulevia tapahtumia';
$string['november'] = 'Marraskuu';
$string['october'] = 'Lokakuu';
$string['oneevent'] = '1 tapahtuma';
$string['pref_lookahead'] = 'Tulevien tapahtumien tarkastelu';
$string['pref_maxevents'] = 'Tulevien tapahtumien listan maksimikoko';
$string['pref_startwday'] = 'Viikon ensimminen piv';
$string['pref_timeformat'] = 'Aikojen muoto';
$string['preferences'] = 'Asetukset';
$string['preferences_available'] = 'Henkilkohtaiset asetuksesi';
$string['repeatnone'] = 'Ei toistoja';
$string['repeatweeksl'] = 'Toista viikoittain';
$string['repeatweeksr'] = 'tapahtumat';
$string['sat'] = 'La';
$string['saturday'] = 'Lauantai';
$string['september'] = 'Syyskuu';
$string['shown'] = 'nkyviss';
$string['spanningevents'] = 'Tapahtumia kynniss parhaillaan';
$string['sun'] = 'Su';
$string['sunday'] = 'Sunnuntai';
$string['thu'] = 'To';
$string['thursday'] = 'Torstai';
$string['timeformat_12'] = '12-tuntinen (AP/IP)';
$string['timeformat_24'] = '24-tuntinen';
$string['today'] = 'Tnn';
$string['tomorrow'] = 'Huomenna';
$string['tt_deleteevent'] = 'Poista tapahtuma';
$string['tt_editevent'] = 'Muokkaa tapahtumaa';
$string['tt_hidecourse'] = 'Kurssin tapahtumat nytetn (klikkaa piilottaaksesi)';
$string['tt_hideglobal'] = 'Yleiset tapahtumat nytetn  (klikkaa piilottaaksesi)';
$string['tt_hidegroups'] = 'Ryhmn tapahtumat nytetn  (klikkaa piilottaaksesi)';
$string['tt_hideuser'] = 'Kyttjn tapahtumat nytetn  (klikkaa piilottaaksesi)';
$string['tt_showcourse'] = 'Kurssin tapahtumat piilotettuna (klikkaa nyttksesi)';
$string['tt_showglobal'] = 'Yleiset tapahtumat piilotettuna (klikkaa nyttksesi)';
$string['tt_showgroups'] = 'Ryhmn tapahtumat piilotettuna (klikkaa nyttksesi)';
$string['tt_showuser'] = 'Kyttjn tapahtumat piilotettuna (klikkaa nyttksesi)';
$string['tue'] = 'Ti';
$string['tuesday'] = 'Tiistai';
$string['typecourse'] = 'Koko kurssille';
$string['typegroup'] = 'Ryhmlle';
$string['typesite'] = 'Koko sivustolle';
$string['typeuser'] = 'Oma tapahtuma';
$string['upcomingevents'] = 'Tulevat tapahtumat';
$string['userevents'] = 'Omat tapahtumat';
$string['wed'] = 'Ke';
$string['wednesday'] = 'Keskiviikko';
$string['yesterday'] = 'Eilen';

?>

==> moodle_1.4.3.orig.tar.gz: moodle/lang/fi/calendar.php <==
<?PHP // $Id$ 
      // calendar.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)


$string['calendar'] = 'Kalenteri';
$string['calendarheading'] = '$a kalenteri';
$string['clickhide'] = 'klikkaa piilottaaksesi';
$string['clickshow'] = 'klikkaa nyttksesi';
$string['confirmeventdelete'] = 'Haluatko varmasti poistaa tmn tapahtuman';
$string['courseevents'] = 'Kurssin tapahtumat';
$string['dayview'] = 'Pivnkym';
$string['daywithnoevents'] = 'Ei tapahtumia tlle pivlle';
$string['default'] = 'Oletus';
$string['deleteevent'] = 'Poista tapahtuma';
$string['detailedmonthview'] = 'Tarkennettu kuukausinkym';
$string['durationminutes'] = 'Kesto minuutteina';
$string['durationnone'] = 'Ilman kestoa';
$string['durationuntil'] = 'Pttymisaika';
$string['editevent'] = 'Muokkaa tapahtumaa';
$string['errorbeforecoursestart'] = 'Tapahtumaa ei voi asettaa alkavaksi ennen kurssin aloituspiv';
$string['errorinvaliddate'] = 'Pivmr virheellinen';
$string['errorinvalidminutes'] = 'Mrit kesto 1 ja 999 minuutin vlilt.';
$string['errorinvalidrepeats'] = 'Mrit tapahtumien mr 1 ja 99 vlill.';
$string['errornodescription'] = 'Tapahtuman kuvaus puuttuu';
$string['errornoeventname'] = 'Tapahtuman nimi puuttuu';
$string['eventdate'] = 'Pivmr';
$string['eventdescription'] = 'Tapahtuman kuvaus';
$string['eventduration'] = 'Kesto';
$string['eventendtime'] = 'Tapahtuman pttymisaika';
$string['eventinstanttime'] = 'Aika';
$string['eventkind'] = 'Tapahtuman tyyppi';
$string['eventname'] = 'Nimi';
$string['eventrepeat'] = 'Toistot';
$string['eventsfor'] = '$a tapahtumaa';
$string['eventstarttime'] = 'Tapahtuman alkamisaika';
$string['eventtime'] = 'Aika';
$string['eventview'] = 'Tapahtumankym';
$string['expired'] = 'Tapahtuma on jo mennyt';
$string['explain_lookahead'] = 'Tm oletusasetus mritt, kuinka monen pivn pss tulevaisuudessa tapahtuman pit olla, jotta se nytettisiin \"tulevana tapahtumana\". Tapahtumia, jotka alkavat myhemmin, ei nytet koskaan tulevien tapahtumien listassa. Huomaa, ett <strong>ei ole mitn takeita</strong> siit, ett kaikki tmn ajan sisll olevat tapahtumat nytettisiin tulevien listassa; mikli niit on paljon (enemmn kuin asetus \"Tulevien tapahtumien listan maksimikoko\", kaukaisimmat tulevista tapahtumista eivt ny listassa.';
$string['explain_maxevents'] = 'Tm asetus mritt tulevien tapahtumien listan maksimikoon. Mikli valitset thn suuren luvun, saattaa tulevien tapahtumien lista vied huomattavan paljon tilaa ruudultasi.';
$string['explain_startwday'] = 'Tm asetus mritt tavan, jolla kuukausittainen kalenteri nytetn. Kyt tt asettaaksesi nkymlle tavan, johon olet tottunut.';
$string['explain_timeformat'] = 'Voit nytt ajat joko 12 tai 24 tunnin muodossa. Jos valitset \"oletus\", valinta suoritetaan sivuston asetusten mukaisesti.';
$string['fri'] = 'Pe';
$string['friday'] = 'Perjantai';
$string['globalevents'] = 'Yhteiset tapahtumat';
$string['gotocalendar'] = 'Siirry kalenteriin';
$string['groupevents'] = 'Ryhmn tapahtumat';
$string['hidden'] = 'Piilotettu';
$string['manyevents'] = '$a tapahtumaa';
$string['mon'] = 'Ma';
$string['monday'] = 'Maanantai';
$string['monthlyview'] = 'Kuukausinkym';
$string['newevent'] = 'Uusi tapahtuma';
$string['noupcomingevents'] = 'Ei tulevia tapahtumia';
$string['oneevent'] = '1 tapahtuma';
$string['pref_lookahead'] = 'Tulevien tapahtumien tarkastelu';
$string['pref_maxevents'] = 'Tulevien tapahtumien listan maksimikoko';
$string['pref_startwday'] = 'Viikon ensimminen piv';
$string['pref_timeformat'] = 'Aikojen muoto';
$string['preferences'] = 'Asetukset';
$string['preferences_available'] = 'Henkilkohtaiset asetuksesi';
$string['repeatnone'] = 'Ei toistoja';
$string['repeatweeksl'] = 'Toista viikoittain';
$string['repeatweeksr'] = 'tapahtumat';
$string['sat'] = 'La';
$string['saturday'] = 'Lauantai';
$string['shown'] = 'nkyviss';
$string['spanningevents'] = 'Tapahtumia kynniss parhaillaan';
$string['sun'] = 'Su';
$string['sunday'] = 'Sunnuntai';
$string['thischarset'] = 'iso-8859-1';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = 'Suomi';
$string['thu'] = 'To';
$string['thursday'] = 'Torstai';
$string['timeformat_12'] = '12-tuntinen (AP/IP)';
$string['timeformat_24'] = '24-tuntinen';
$string['today'] = 'Tnn';
$string['tomorrow'] = 'Huomenna';
$string['tt_deleteevent'] = 'Poista tapahtuma';
$string['tt_editevent'] = 'Muokkaa tapahtumaa';
$string['tt_hidecourse'] = 'Kurssin tapahtumat nytetn (piiloita)';
$string['tt_hideglobal'] = 'Yleiset tapahtumat nytetn  (piiloita)';
$string['tt_hidegroups'] = 'Ryhmn tapahtumat nytetn  (piiloita)';
$string['tt_hideuser'] = 'Kyttjn tapahtumat nytetn  (piiloita)';
$string['tt_showcourse'] = 'Kurssin tapahtumat piilotettuna (nyt)';
$string['tt_showglobal'] = 'Yleiset tapahtumat piilotettuna (nyt)';
$string['tt_showgroups'] = 'Ryhmn tapahtumat piilotettuna (nyt)';
$string['tt_showuser'] = 'Kyttjn tapahtumat piilotettuna (nyt)';
$string['tue'] = 'Ti';
$string['tuesday'] = 'Tiistai';
$string['typecourse'] = 'Koko kurssille';
$string['typegroup'] = 'Ryhmlle';
$string['typesite'] = 'Koko sivustolle';
$string['typeuser'] = 'Oma tapahtuma';
$string['upcomingevents'] = 'Tulevat tapahtumat';
$string['userevents'] = 'Omat tapahtumat';
$string['wed'] = 'Ke';
$string['wednesday'] = 'Keskiviikko';
$string['yesterday'] = 'Eilen';

?>
